import sys
import os
import shutil
import zlib
import binascii

import json

def crc(s):     # CRC-32 of string s
    return binascii.crc32(s) & 0xffffffff

def chunkify(dir, app, original, chunk_size):
    if os.path.exists(dir):
        shutil.rmtree(dir)
    os.makedirs(dir)

    chunks = [original[i:i+chunk_size] for i in range(0, len(original), chunk_size)]
    for (i, chunk) in enumerate(chunks):
        with open(f"{dir}/{app}.tape-chunk_{i:03d}", 'wb') as f:
            f.write(chunk)

    return len(chunks)

def expand(tapefile):
    print(tapefile)
    basename = tapefile.replace(".tape", "")
    app,version = basename.split("-")
    dir = basename

    with open(tapefile, "rb") as f:
        tape = f.read()

    chunk_size = 2 * 1024
    n_f1 = chunkify(dir, app, tape, chunk_size)
    n_f2 = chunkify(dir + "_F2", app, zlib.compress(tape), 14 * 1024)

    data = {
        "app"         : app,
        "version"     : version,
        "sha"         : "07bb0061886ebf1d42db3f98583b2171e01ff31b",
        "chunk_size"  : str(chunk_size),
        "chunk_count" : str(n_f1),
        "F2"          : {
            "tape_size"     : len(tape),
            "tape_crc"      : crc(tape),
            "chunk_count"   : str(n_f2),
        },
    }
    with open(f"{dir}/metadata.json", 'w') as f:
        json.dump(data, f)

if __name__ == "__main__":
    for arg in sys.argv[1:]:
        expand(sys.argv[1])
